@@ -1,9 +1,9 @@
 /***************************************************************************
-                   xmmsinterface.cpp  -  Interface to access XMMS
+                          Interface to access XMMS
                              -------------------
     begin                : Tue Apr 25 11:53:11 CEST 2000
     copyright            : (C) 2000-2002 by Stefan Gehn
-    email                : sgehn@gmx.net
+    email                : metz {AT} gehn {DOT} net
  ***************************************************************************/
 
 /***************************************************************************
@@ -33,6 +33,7 @@
 XmmsInterface::XmmsInterface() : PlayerInterface()
 {
 	timervalue = TIMER_FAST;
+	bStartingXMMS = false;
 	xmms_timer = new QTimer ( this, "xmms_timer" );
 
 	QObject::connect( xmms_timer, SIGNAL(timeout()), SLOT(updateSlider()) );
@@ -120,7 +121,19 @@ void XmmsInterface::jumpToTime( int msec )
 
 void XmmsInterface::playpause()
 {
-	xmms_remote_play_pause(XMMS_SESSION);
+	if (!xmms_remote_is_running(XMMS_SESSION))
+	{
+		if (bStartingXMMS)
+			return;
+		startPlayer("xmms");
+		bStartingXMMS = true;
+		QTimer::singleShot(500, this, SLOT(playpause()));
+	}
+	else
+	{
+		bStartingXMMS = false;
+		xmms_remote_play_pause(XMMS_SESSION);
+	}
 }
 
 void XmmsInterface::stop()
