@@ -22,6 +22,7 @@
 #include <qmap.h>
 #include <qstringlist.h>
 
+
 #include <kurl.h>
 #include <kfileitem.h>
 #include <klibloader.h>
@@ -29,6 +30,8 @@
 
 class KActionMenu;
 class KonqDirPart;
+class KLineEdit;
+
 
 namespace KParts
 {
@@ -46,15 +49,17 @@ public:
 
   ~SessionManager ();
   static SessionManager* self ();
-  QStringList restore (const KURL& url);
+  QStringList restoreMimeFilters (const KURL& url) const;
+  QString restoreTypedFilter(const KURL& url) const;
   void save (const KURL& url, const QStringList& filters);
+  void save (const KURL& url, const QString& typedFilter);
 
   bool showCount;
   bool useMultipleFilters;
 
 protected:
 
-  QString generateKey (const KURL& url);
+  QString generateKey (const KURL& url) const;
   void loadSettings ();
   void saveSettings ();
 
@@ -68,6 +73,7 @@ private:
   bool m_bSettingsLoaded;
   static SessionManager* m_self;
   QMap<QString,QStringList> m_filters;
+  QMap<QString,QString> m_typedFilter;
 };
 
 
@@ -88,7 +94,7 @@ protected:
     {
       id = 0;
       useAsFilter = false;
-    };
+    }
 
     int id;
     bool useAsFilter;
@@ -119,6 +125,7 @@ private:
   KonqDirPart* m_part;
   KActionMenu* m_pFilterMenu;
 
+  KLineEdit *m_searchWidget;
   QMap<QString,MimeInfo> m_pMimeInfo;
   typedef QMap<QString,MimeInfo>::Iterator MimeInfoIterator;
 };
